Functionals
===========

.. automodule:: mumott.methods.functionals

.. index::
   single: Class reference; SIGTT
.. autoclass:: mumott.methods.functionals.SIGTT
   :members:
   :undoc-members:
   :inherited-members:
